@@ -1,4 +1,4 @@
-﻿// PlayerBin.cs 
+// PlayerBin.cs 
 //
 //  Copyright (C) 2007-2009 Andoni Morales Alastruey
 //
@@ -22,10 +22,10 @@ using Gtk;
 using Gdk;
 using Mono.Unix;
 using System.Runtime.InteropServices;
-using LongoMatch.Video.Handlers;
+using LongoMatch.Video;
+using LongoMatch.Video.Common;
 using LongoMatch.Video.Player;
 using LongoMatch.Video.Utils;
-using LongoMatch.Video;
 
 namespace LongoMatch.Gui
 {
@@ -38,7 +38,7 @@ namespace LongoMatch.Gui
 		public event SegmentClosedHandler SegmentClosedEvent;
 		public event TickHandler Tick;
 		public event ErrorHandler Error;
-		public event StateChangeHandler StateChanged;
+		public event StateChangeHandler PlayStateChanged;
 		public event NextButtonClickedHandler Next;
 		public event PrevButtonClickedHandler Prev;
 		public event DrawFrameHandler DrawFrame;
@@ -51,8 +51,8 @@ namespace LongoMatch.Gui
 		private string slength;
 		private long segmentStartTime;
 		private long segmentStopTime;
-		private bool hasNext;
 		private bool seeking=false;
+		private double[] seeksQueue; 
 		private bool IsPlayingPrevState = false;
 		private float rate=1;
 		private double previousVLevel = 1;
@@ -61,6 +61,7 @@ namespace LongoMatch.Gui
 		//the player.mrl is diferent from the filename as it's an uri eg:file:///foo.avi
 		private string filename = null;
 		protected VolumeWindow vwin;
+		
 				
 #region Constructors		
 		public PlayerBin()
@@ -73,6 +74,16 @@ namespace LongoMatch.Gui
 			UnSensitive();
 			timescale.Adjustment.PageIncrement = 0.01;
 			timescale.Adjustment.StepIncrement = 0.0001;
+			playbutton.CanFocus = false;
+			prevbutton.CanFocus = false;
+			nextbutton.CanFocus = false;
+			volumebutton.CanFocus = false;
+			timescale.CanFocus = false;
+			vscale1.CanFocus = false;	
+			drawbutton.CanFocus = false;
+			seeksQueue = new double[2];
+			seeksQueue [0] = 0;
+			seeksQueue [1] = 0;
 		}
 		
 #endregion
@@ -193,7 +204,6 @@ namespace LongoMatch.Gui
 		}
 	
 		public void SetPlayListElement(string fileName,long start, long stop, float rate, bool hasNext){
-			this.hasNext = hasNext;
 			if (hasNext)
 				nextbutton.Sensitive = true;
 			else
@@ -251,17 +261,11 @@ namespace LongoMatch.Gui
 		}
 		
 		public void StepForward(){
-			seeking = true;
-			timescale.Adjustment.Value += timescale.Adjustment.PageIncrement;
-			OnTimescaleAdjustBounds(null, null);
-			seeking = false;
+			SeekFromTimescale(timescale.Value + timescale.Adjustment.PageIncrement);
 		}
 		
-		public void StepBackward(){
-			seeking = true;
-			timescale.Adjustment.Value -= timescale.Adjustment.PageIncrement;
-			OnTimescaleAdjustBounds(null, null);
-			seeking = false;			
+		public void StepBackward(){			
+			SeekFromTimescale(timescale.Value - timescale.Adjustment.PageIncrement);
 		}
 		
 		public void FramerateUp(){
@@ -297,7 +301,6 @@ namespace LongoMatch.Gui
 		
 		public void CloseActualSegment(){
 			closebutton.Hide();
-			hasNext = false;
 			segmentStartTime = 0;
 			segmentStopTime = 0;
 			vscale1.Value=25;
@@ -347,7 +350,7 @@ namespace LongoMatch.Gui
 			
 			tickHandler = new TickHandler(OnTick);
 			player.Tick += tickHandler;
-			player.StateChange += new LongoMatch.Video.Handlers.StateChangeHandler(OnStateChanged);
+			player.StateChange += new StateChangeHandler(OnStateChanged);
 			player.Eos += new EventHandler (OnEndOfStream);
 			player.Error += new ErrorHandler (OnError);
 			player.ReadyToSeek += new EventHandler(OnReadyToSeek);
@@ -359,10 +362,24 @@ namespace LongoMatch.Gui
 				
 		}
 		
+		private void SeekFromTimescale(double pos){						
+			if (InSegment()){
+				long seekPos = segmentStartTime + (long)(pos*(segmentStopTime-segmentStartTime));
+				player.SeekInSegment(seekPos, GetRateFromScale());	
+				timelabel.Text= TimeString.MSecondsToSecondsString(seekPos) + "/" + 
+					TimeString.MSecondsToSecondsString(segmentStopTime-segmentStartTime);
+			}
+			else {
+				player.Position = pos;
+				timelabel.Text= TimeString.MSecondsToSecondsString(player.CurrentTime) + "/" + slength;
+				Rate = 1;				
+			}	
+		}
+		
 #endregion
 		
 #region Callbacks
-		protected virtual void OnStateChanged(object o, LongoMatch.Video.Handlers.StateChangeArgs args){
+		protected virtual void OnStateChanged(object o, StateChangeArgs args){
 			if (args.Playing){
 				playbutton.Hide();
 				pausebutton.Show();
@@ -371,8 +388,8 @@ namespace LongoMatch.Gui
 				playbutton.Show();
 				pausebutton.Hide();
 			}
-			if (StateChanged != null)
-				StateChanged(this,args);
+			if (PlayStateChanged != null)
+				PlayStateChanged(this,args);
 		}
 		
 		protected void OnReadyToSeek(object o, EventArgs args){
@@ -390,7 +407,6 @@ namespace LongoMatch.Gui
 			long currentTime = args.CurrentTime;
 			float currentposition = args.CurrentPosition;		
 			long streamLength = args.StreamLength;		
-			bool seekable = args.Seekable;
 			
 			//Console.WriteLine ("Current Time:{0}\n Length:{1}\n",currentTime, streamLength);
 			if (length != streamLength){							
@@ -413,33 +429,30 @@ namespace LongoMatch.Gui
 		
 		protected virtual void OnTimescaleAdjustBounds(object o, Gtk.AdjustBoundsArgs args)
 		{
-			float pos;		
+			double pos;		
 			
 			if (!seeking){
 				seeking = true;
 				IsPlayingPrevState = player.Playing;
 				player.Tick -= tickHandler;
 				player.Pause();
+				seeksQueue [0] = 0;
+				seeksQueue [1] = 0;
 			}
-				
-			pos = (float)timescale.Value;			
 			
-			if (InSegment()){
-				long seekPos = segmentStartTime + (long)(pos*(segmentStopTime-segmentStartTime));
-				player.SeekInSegment(seekPos, GetRateFromScale());	
-				timelabel.Text= TimeString.MSecondsToSecondsString(seekPos) + "/" + 
-					TimeString.MSecondsToSecondsString(segmentStopTime-segmentStartTime);
-			}
-			else {
-				player.Position = pos;
-				timelabel.Text= TimeString.MSecondsToSecondsString(player.CurrentTime) + "/" + slength;
-				Rate = 1;				
-			}			
+			pos = timescale.Value;	
+			seeksQueue[0] = seeksQueue[1];
+			seeksQueue[1] = pos;
+			
+			SeekFromTimescale(pos);		
 		}		
 
 		protected virtual void OnTimescaleValueChanged(object sender, System.EventArgs e)
 		{
 			if (seeking){
+				/* Releasing the timescale always report value different from the real one. 
+				 * We need to cache previous position and seek again to the this position */				
+				SeekFromTimescale(seeksQueue[0]);
 				seeking=false;				
 				player.Tick += tickHandler;
 				if (IsPlayingPrevState)
@@ -563,7 +576,6 @@ namespace LongoMatch.Gui
 		protected virtual void OnDrawButtonClicked (object sender, System.EventArgs e)
 		{
 			int currentTime;
-			Pixbuf frame=null;
 			
 			currentTime = (int)AccurateCurrentTime;
 			// If the player has reached the end of the segment the current time
