@@ -1,4 +1,4 @@
-﻿// FileDescriptionWidget.cs
+// FileDescriptionWidget.cs
 //
 //  Copyright (C) 2007-2009 Andoni Morales Alastruey
 //
@@ -19,6 +19,7 @@
 //
 
 using System;
+using System.Collections.Generic;
 using Mono.Unix;
 using Gtk;
 using LongoMatch.Common;
@@ -29,7 +30,8 @@ using LongoMatch.Gui.Popup;
 using LongoMatch.Gui.Dialog;
 using LongoMatch.TimeNodes;
 using LongoMatch.Video.Utils;
-
+using LongoMatch.Video.Capturer;
+using LongoMatch.Video.Common;
 
 namespace LongoMatch.Gui.Component
 {
@@ -51,44 +53,55 @@ namespace LongoMatch.Gui.Component
 		private TeamTemplate actualVisitorTeam;
 		private TeamTemplate actualLocalTeam;
 		private ProjectType useType;
-
+		private List<Device> videoDevices;
+		private const string PAL_FORMAT = "720x576 (4:3)";
+		private const string PAL_3_4_FORMAT = "540x432 (4:3)";
+		private const string PAL_1_2_FORMAT = "360x288 (4:3)";
+		private const string DV_SOURCE = "DV Source";
+		private const string GCONF_SOURCE = "GConf Source";
+		
+		
 		public ProjectDetailsWidget()
 		{
 			this.Build();
 
 			//HACK:The calendar dialog does not respond on win32
-			if (Environment.OSVersion.Platform != PlatformID.Win32NT) {
+			if (Environment.OSVersion.Platform == PlatformID.Win32NT) {
 				cp = new CalendarPopup();
 				cp.Hide();
 				cp.DateSelectedEvent += new DateSelectedHandler(OnDateSelected);
 			}
-
+			
 			FillSections();
 			FillTeamsTemplate();
+			FillFormats();
+			
+			videoDevices = new List<Device>();
 
-			this.Use=ProjectType.FileProject;
+			Use=ProjectType.FileProject;
 		}
 
 		public ProjectType Use {
 			set {
-				if (value == ProjectType.FileProject  || value == ProjectType.EditProject
-				    || value == ProjectType.FakeCaptureProject) {
-					videobitratelabel.Visible = false;
-					bitratespinbutton.Visible = false;					
-				}
-				if (value == ProjectType.FakeCaptureProject) {
-					label6.Visible = false;
-					hbox4.Visible = false;
-				}
-				if (value == ProjectType.EditProject) {
-					tagscombobox.Visible = false;
-					localcombobox.Visible = false;
-					visitorcombobox.Visible = false;
-				}
+				bool visible1 = value == ProjectType.CaptureProject; 
+				bool visible2 = value != ProjectType.FakeCaptureProject;
+				bool visible3 = value != ProjectType.EditProject;
+				
+				filelabel.Visible = visible2;
+				filehbox.Visible = visible2;
+				
+				tagscombobox.Visible = visible3;
+				localcombobox.Visible = visible3;
+				visitorcombobox.Visible = visible3;
+				
+				expander1.Visible = visible1;
+				device.Visible = visible1;
+				devicecombobox.Visible = visible1;
+				
 				useType = value;
 			}
 			get {
-				return this.useType;
+				return useType;
 			}
 		}
 
@@ -106,7 +119,7 @@ namespace LongoMatch.Gui.Component
 				return localTeamEntry.Text;
 			}
 			set {
-				this.localTeamEntry.Text = value;
+				localTeamEntry.Text = value;
 			}
 		}
 
@@ -115,7 +128,7 @@ namespace LongoMatch.Gui.Component
 				return visitorTeamEntry.Text;
 			}
 			set {
-				this.visitorTeamEntry.Text = value;
+				visitorTeamEntry.Text = value;
 			}
 		}
 
@@ -142,7 +155,7 @@ namespace LongoMatch.Gui.Component
 				return (int)localSpinButton.Value;
 			}
 			set {
-				this.localSpinButton.Value = value;
+				localSpinButton.Value = value;
 			}
 		}
 
@@ -176,7 +189,7 @@ namespace LongoMatch.Gui.Component
 
 		public Sections Sections {
 			get {
-				return this.actualSection;
+				return actualSection;
 			}
 			set {
 				actualSection = value;
@@ -218,7 +231,70 @@ namespace LongoMatch.Gui.Component
 				return visitorcombobox.ActiveText + ".tem";
 			}
 		}
-
+		
+		public CapturePropertiesStruct CaptureProperties{
+			get{
+				CapturePropertiesStruct s = new CapturePropertiesStruct();
+				s.OutputFile = fileEntry.Text;
+				s.AudioBitrate = (uint)audiobitratespinbutton.Value;
+				s.VideoBitrate = (uint)videobitratespinbutton.Value;
+				if (videoDevices[devicecombobox.Active].DeviceType == DeviceType.DV){
+					if (Environment.OSVersion.Platform == PlatformID.Win32NT)
+						s.CaptureSourceType = CaptureSourceType.DShow;
+					else
+						s.CaptureSourceType = CaptureSourceType.DV;
+				}
+				else {
+					s.CaptureSourceType = CaptureSourceType.Raw;
+				}
+				s.DeviceID = videoDevices[devicecombobox.Active].ID;
+				/* Get size info */
+				switch (sizecombobox.ActiveText){
+					/* FIXME: Don't harcode size values */
+					case PAL_FORMAT:
+						s.Width = 720;
+						s.Height = 576;
+						break;
+					case PAL_3_4_FORMAT:
+						s.Width = 540;
+						s.Height = 432;
+						break;
+					case PAL_1_2_FORMAT:
+						s.Width = 360;
+						s.Height = 288;
+						break;
+					default:
+						s.Width = 0;
+						s.Height = 0;
+						break;
+				}
+				/* Get video compresion format info */
+				switch (videoformatcombobox.ActiveText){
+					case Constants.AVI:
+						s.VideoEncoder = VideoEncoderType.Mpeg4;
+						s.AudioEncoder = AudioEncoderType.Mp3;
+						s.Muxer = VideoMuxerType.Avi;
+						break;
+					case Constants.MP4:
+						s.VideoEncoder = VideoEncoderType.H264;
+						s.AudioEncoder = AudioEncoderType.Aac;
+						s.Muxer = VideoMuxerType.Mp4;
+						break;
+					case Constants.OGG:
+						s.VideoEncoder = VideoEncoderType.Theora;
+						s.AudioEncoder = AudioEncoderType.Vorbis;
+						s.Muxer = VideoMuxerType.Ogg;
+						break;
+					case Constants.WEBM:
+						s.VideoEncoder = VideoEncoderType.VP8;
+						s.AudioEncoder = AudioEncoderType.Vorbis;
+						s.Muxer = VideoMuxerType.WebM;
+						break;
+				}
+				return s;
+			}
+		}
+		
 		public void SetProject(Project project) {
 			this.project = project;
 			mFile = project.File;
@@ -252,14 +328,18 @@ namespace LongoMatch.Gui.Component
 
 		public Project GetProject() {
 			if (useType != ProjectType.EditProject) {
-				if (Filename == "" && useType == ProjectType.FileProject)
+				if (Filename == "" && useType != ProjectType.FakeCaptureProject)
 					return null;
 				else {
 					if (useType == ProjectType.FakeCaptureProject){
 						mFile = new PreviewMediaFile();
 						mFile.FilePath = Constants.FAKE_PROJECT;
 						mFile.Fps = 25;
-					}					
+					} else if  (useType == ProjectType.CaptureProject){
+						mFile = new PreviewMediaFile();
+						mFile.FilePath = fileEntry.Text;
+						mFile.Fps = 25;
+					}
 					return new Project(mFile,
 					                   LocalName,
 					                   VisitorName,
@@ -293,6 +373,25 @@ namespace LongoMatch.Gui.Component
 			mFile = null;
 			edited = false;
 		}
+		
+		public void FillDevices(List<Device> devices){
+			videoDevices = devices;
+			
+			foreach (Device device in devices){
+				string deviceElement;
+				string deviceName;
+				if (Environment.OSVersion.Platform == PlatformID.Unix){
+					if (device.DeviceType == DeviceType.DV)
+						deviceElement = Catalog.GetString(DV_SOURCE);
+					else 
+						deviceElement = Catalog.GetString(GCONF_SOURCE);
+				} else 
+					deviceElement = Catalog.GetString("DirectShow Source");
+				deviceName = (device.ID == "") ? Catalog.GetString("Unknown"): device.ID;
+				devicecombobox.AppendText(deviceName + " ("+deviceElement+")");
+				devicecombobox.Active = 0;
+			}
+		}
 
 		private void FillSections() {
 			string[] allFiles;
@@ -310,7 +409,7 @@ namespace LongoMatch.Gui.Component
 			}
 			tagscombobox.Active = index;
 			SectionsReader reader = new SectionsReader(System.IO.Path.Combine(MainClass.TemplatesDir(),SectionsFile));
-			this.Sections= reader.GetSections();
+			Sections= reader.GetSections();
 		}
 
 		private void FillTeamsTemplate() {
@@ -334,7 +433,22 @@ namespace LongoMatch.Gui.Component
 			LocalTeamTemplate = TeamTemplate.LoadFromFile(System.IO.Path.Combine(MainClass.TemplatesDir(),LocalTeamTemplateFile));
 			VisitorTeamTemplate = TeamTemplate.LoadFromFile(System.IO.Path.Combine(MainClass.TemplatesDir(),VisitorTeamTemplateFile));
 		}
-
+		
+		private void FillFormats(){
+			sizecombobox.AppendText (Catalog.GetString("Keep original size"));
+			sizecombobox.AppendText(PAL_FORMAT);
+			sizecombobox.AppendText(PAL_3_4_FORMAT);
+			sizecombobox.AppendText(PAL_1_2_FORMAT);
+			sizecombobox.Active = 0;
+		
+			videoformatcombobox.AppendText(Constants.AVI);
+			if (Environment.OSVersion.Platform != PlatformID.Win32NT)
+				videoformatcombobox.AppendText(Constants.WEBM);
+			videoformatcombobox.AppendText(Constants.OGG);
+			videoformatcombobox.AppendText(Constants.MP4);
+			videoformatcombobox.Active = 0;
+		}
+		
 		protected virtual void OnDateSelected(DateTime dateTime) {
 			Date = dateTime;
 		}
@@ -343,13 +457,14 @@ namespace LongoMatch.Gui.Component
 		{
 			FileChooserDialog fChooser = null;
 
-			if (this.useType == ProjectType.CaptureProject) {
-				fChooser = new FileChooserDialog(Catalog.GetString("Save File as..."),
+			if (useType == ProjectType.CaptureProject) {
+				fChooser = new FileChooserDialog(Catalog.GetString("Output file"),
 				                                 (Gtk.Window)this.Toplevel,
 				                                 FileChooserAction.Save,
 				                                 "gtk-cancel",ResponseType.Cancel,
 				                                 "gtk-save",ResponseType.Accept);
 				fChooser.SetCurrentFolder(MainClass.VideosDir());
+				fChooser.DoOverwriteConfirmation = true;
 				if (fChooser.Run() == (int)ResponseType.Accept)
 					fileEntry.Text = fChooser.Filename;
 				fChooser.Destroy();
@@ -376,6 +491,12 @@ namespace LongoMatch.Gui.Component
 						md.Icon=Stetic.IconLoader.LoadIcon(this, "longomatch", Gtk.IconSize.Dialog, 48);
 						md.Show();
 						mFile = LongoMatch.Video.Utils.PreviewMediaFile.GetMediaFile(filename);
+						if (!mFile.HasVideo || mFile.VideoCodec == "")
+							throw new Exception(Catalog.GetString("This file doesn't contain a video stream."));
+						if (mFile.HasVideo && mFile.Length == 0)
+							throw new Exception(Catalog.GetString("This file contains a video stream but its length is 0."));
+						
+							
 						fileEntry.Text = filename;
 					}
 					catch (Exception ex) {
@@ -431,7 +552,7 @@ namespace LongoMatch.Gui.Component
 			ted.Project = project;
 			ted.CanExport = Use == ProjectType.EditProject;
 			if (ted.Run() == (int)ResponseType.Apply) {
-				this.Sections = ted.Sections;
+				Sections = ted.Sections;
 			}
 			ted.Destroy();
 			OnEdited(this,null);
