@@ -1,4 +1,4 @@
-﻿// MainWindow.cs
+// MainWindow.cs
 //
 //  Copyright (C) 2007-2009 Andoni Morales Alastruey
 //
@@ -18,26 +18,22 @@
 //
 //
 
-using System;
-using Gtk;
-using Mono.Unix;
-using System.IO;
-using GLib;
-using System.Threading;
 using Gdk;
+using GLib;
+using Gtk;
 using LongoMatch.Common;
 using LongoMatch.DB;
-using LongoMatch.TimeNodes;
 using LongoMatch.Gui.Dialog;
-using LongoMatch.Gui.Popup;
-using LongoMatch.Video;
+using LongoMatch.Handlers;
+using LongoMatch.TimeNodes;
+using LongoMatch.Utils;
 using LongoMatch.Video.Capturer;
+using LongoMatch.Video.Common;
 using LongoMatch.Video.Player;
 using LongoMatch.Video.Utils;
-using LongoMatch.Updates;
-using LongoMatch.Utils;
-using LongoMatch.IO;
-using LongoMatch.Handlers;
+using Mono.Unix;
+using System;
+using System.IO;
 using System.Reflection;
 
 
@@ -56,7 +52,6 @@ namespace LongoMatch.Gui
 		private HotKeysManager hkManager;
 		private KeyPressEventHandler hotkeysListener;
 		
-		private CapturerBin capturerBin;		
 		
 		#region Constructors
 		public MainWindow() :
@@ -65,6 +60,7 @@ namespace LongoMatch.Gui
 			this.Build();
 
 			/*Updater updater = new Updater();
+			A
 			updater.NewVersion += new LongoMatch.Handlers.NewVersionHandler(OnUpdate);
 			updater.Run();*/
 			
@@ -79,7 +75,8 @@ namespace LongoMatch.Gui
 			                             playerbin1,
 			                             timelinewidget1,
 			                             videoprogressbar,
-			                             noteswidget1);
+			                             noteswidget1,
+			                             capturerBin);
 
 			hkManager = new HotKeysManager();
 			// Listenning only when a project is loaded
@@ -94,6 +91,11 @@ namespace LongoMatch.Gui
 			playerbin1.SetLogo(System.IO.Path.Combine(MainClass.ImagesDir(),"background.png"));
 			playerbin1.LogoMode = true;
 			
+			capturerBin.Visible = false;
+			capturerBin.Logo = System.IO.Path.Combine(MainClass.ImagesDir(),"background.png");
+			capturerBin.CaptureFinished += delegate {
+						CloseCaptureProject();};
+			
 			buttonswidget1.Mode = TagMode.Predifined;
 
 			playlistwidget2.SetPlayer(playerbin1);
@@ -105,98 +107,159 @@ namespace LongoMatch.Gui
 		#endregion
 		
 		#region Private Methods
-		private void SetProject(Project project, ProjectType projectType) {
+		private void SetProject (Project project, ProjectType projectType, CapturePropertiesStruct props)
+		{
+			bool isLive = false;
+			
 			if (project == null)
 				return;
 			
-			CloseOpenedProject(true);
+			if (openedProject != null)
+				CloseOpenedProject (true);
+			
 			openedProject = project;
 			this.projectType = projectType;
 			eManager.OpenedProject = project;
 			eManager.OpenedProjectType = projectType;
 			
-			if (projectType == ProjectType.FileProject){
+			/* Update tabs labels */
+			/* FIXME 1.0: Teams should have default names */
+			if (project.VisitorName == "")
+				visitorteamlabel.Text = Catalog.GetString("Visitor Team");
+			else
+				visitorteamlabel.Text = project.VisitorName;
+			if (project.LocalName == "")
+				localteamlabel.Text = Catalog.GetString("Local Team");
+			else
+				localteamlabel.Text = project.LocalName;
+				
+			if (projectType == ProjectType.FileProject) {
 				// Check if the file associated to the project exists
-				if (!File.Exists(project.File.FilePath)) {
-					MessagePopup.PopupMessage(this, MessageType.Warning,
-					                          Catalog.GetString("The file associated to this project doesn't exist.")+"\n"
-					                          +Catalog.GetString("If the location of the file has changed try to edit it with the database manager."));
-					CloseOpenedProject(false);
+				if (!File.Exists (project.File.FilePath)) {
+					MessagePopup.PopupMessage (this, MessageType.Warning,
+					                           Catalog.GetString ("The file associated to this project doesn't exist.") + "\n"
+					                           + Catalog.GetString ("If the location of the file has changed try to edit it with the database manager."));
+					CloseOpenedProject (true);
 					return;
-				} else {
-					Title = System.IO.Path.GetFileNameWithoutExtension(project.File.FilePath) + " - LongoMatch";
+				}
+				Title = System.IO.Path.GetFileNameWithoutExtension (project.File.FilePath) + 
+					" - " +	Constants.SOFTWARE_NAME;
+				try {
+					playerbin1.Open (project.File.FilePath);
+				}
+				catch (GLib.GException ex) {
+					MessagePopup.PopupMessage (this, MessageType.Error,
+					                           Catalog.GetString ("An error occurred opening this project:") + "\n" + ex.Message);
+					CloseOpenedProject (true);
+						return;
+				}
+				playerbin1.LogoMode = false;
+				timelinewidget1.Project = project;
+				
+			} else {
+				Title = Constants.SOFTWARE_NAME;
+				isLive = true;
+				if (projectType == ProjectType.CaptureProject) {
+					capturerBin.CaptureProperties = props;
 					try {
-						playerbin1.Open(project.File.FilePath);							
-					}
-					catch (GLib.GException ex) {
-						MessagePopup.PopupMessage(this, MessageType.Error,
-						                          Catalog.GetString("An error occurred opening this project:")+"\n"+ex.Message);
-						CloseOpenedProject(false);
+						capturerBin.Type = CapturerType.Live;
+					} catch (Exception ex) {
+						MessagePopup.PopupMessage (this, MessageType.Error, ex.Message);
+						CloseOpenedProject (false);
 						return;
 					}
-					playerbin1.LogoMode = false;
-					timelinewidget1.Project = project;
-					treewidget1.ProjectIsLive = false;
-					localplayerslisttreewidget.ProjectIsLive = false;
-					visitorplayerslisttreewidget.ProjectIsLive = false;
-					tagstreewidget1.ProjectIsLive = false;						
-				} 
-			}else {
-				Title = "LongoMatch";
-				playerbin1.Visible = false;					
-				capturerBin = new CapturerBin();
-				capturerBin.Logo = System.IO.Path.Combine(MainClass.ImagesDir(),"background.png");
-				capturerBin.CaptureFinished += delegate {
-					CloseOpenedProject(true);	
-				};
-				eManager.Capturer = capturerBin;
-				hbox2.Add(capturerBin);
-				(capturerBin).Show();	
-				treewidget1.ProjectIsLive = true;
-				localplayerslisttreewidget.ProjectIsLive = true;
-				visitorplayerslisttreewidget.ProjectIsLive = true;
-				tagstreewidget1.ProjectIsLive = true;	
+				} else
+					capturerBin.Type = CapturerType.Fake;
+				playerbin1.Visible = false;
+				capturerBin.Visible = true;
+				capturerBin.Run ();
 				CaptureModeAction.Active = true;
-			}	
+			}
 			
+			treewidget1.ProjectIsLive = isLive;
+			localplayerslisttreewidget.ProjectIsLive = isLive;
+			visitorplayerslisttreewidget.ProjectIsLive = isLive;
+			tagstreewidget1.ProjectIsLive = isLive;
 			playlistwidget2.Stop();
 			treewidget1.Project=project;
 			localplayerslisttreewidget.SetTeam(project.LocalTeamTemplate,project.GetLocalTeamModel());
 			visitorplayerslisttreewidget.SetTeam(project.VisitorTeamTemplate,project.GetVisitorTeamModel());
 			tagstreewidget1.Project = project;				
 			buttonswidget1.Sections = project.Sections;
+			hkManager.Sections=project.Sections;
+			KeyPressEvent += hotkeysListener;
 			MakeActionsSensitive(true,projectType);
 			ShowWidgets();
-			hkManager.Sections=project.Sections;
-			KeyPressEvent += hotkeysListener;			
+	}
+		
+		private void SaveCaptureProject(){
+			PreviewMediaFile file;
+			Project newProject = openedProject;
+			string filePath = openedProject.File.FilePath;
+			
+			MessageDialog md = new MessageDialog((Gtk.Window)this.Toplevel, DialogFlags.Modal, MessageType.Info, ButtonsType.None,
+			                                     Catalog.GetString("Loading newly created project..."));
+			md.Show();
+
+			/* scan the new file to build a new PreviewMediaFile with all the metadata */
+			try{
+				file = PreviewMediaFile.GetMediaFile(filePath);		
+				openedProject.File = file;
+				MainClass.DB.AddProject(openedProject);
+			} catch (Exception ex){
+				string projectFile = filePath + "-" + DateTime.Now;
+				Project.Export(openedProject, projectFile);
+				MessagePopup.PopupMessage(this, MessageType.Error,
+				                          Catalog.GetString("An error occured saving the project:\n")+ex.Message+ "\n\n"+
+				                          Catalog.GetString("The video file and a backup of the project has been "+
+				                                            "saved. Try to import it later:\n")+
+				                          filePath+"\n"+projectFile);
+			}
+			/* we need to set the opened project to null to avoid calling again CloseOpendProject() */
+			openedProject = null;
+			SetProject(newProject, ProjectType.FileProject, new CapturePropertiesStruct());
+			md.Destroy();
 		}
 		
+		private void CloseCaptureProject (){
+			if (projectType == ProjectType.CaptureProject){
+				capturerBin.Close();
+				playerbin1.Visible = true;
+				capturerBin.Visible = false;;
+				SaveCaptureProject();
+			} else if (projectType == ProjectType.FakeCaptureProject){
+				CloseOpenedProject(true);
+			}
+		}
+
 		private void CloseOpenedProject(bool save) {
-			bool playlistVisible = playlistwidget2.Visible;			
-			
 			if (save)
 				SaveProject();
 			
-			if (projectType != ProjectType.FileProject){
-				playerbin1.Visible = true;
-				eManager.Capturer = null;
-				if (capturerBin != null)
-					capturerBin.Destroy();
-			} else {
+			if (projectType != ProjectType.FileProject)
+				capturerBin.Close();
+			else 
 				playerbin1.Close();
-				playerbin1.LogoMode = true;
-			}
-			Title = "LongoMatch";
+			
+			if (openedProject != null)
+				openedProject.Clear();
+			openedProject = null;
+			projectType = ProjectType.None;
+			eManager.OpenedProject = null;
+			eManager.OpenedProjectType = ProjectType.None;				
+			ResetGUI();
+		}
+		
+		private void ResetGUI(){
+			bool playlistVisible = playlistwidget2.Visible;	
+
+			Title = Constants.SOFTWARE_NAME;
+			playerbin1.Visible = true;
+			playerbin1.LogoMode = true;
+			capturerBin.Visible = false;
 			ClearWidgets();
 			HideWidgets();	
 			
-			if (openedProject != null) {
-				openedProject.Clear();
-				openedProject = null;
-				projectType = ProjectType.None;
-				eManager.OpenedProject = null;
-				eManager.OpenedProjectType = ProjectType.None;				
-			}			
 			playlistwidget2.Visible = playlistVisible;
 			rightvbox.Visible = playlistVisible;
 			noteswidget1.Visible = false;			
@@ -243,7 +306,11 @@ namespace LongoMatch.Gui
 
 		private void SaveProject() {
 			if (openedProject != null && projectType == ProjectType.FileProject) {
-				MainClass.DB.UpdateProject(openedProject);
+				try {
+					MainClass.DB.UpdateProject(openedProject);
+				} catch (Exception e){
+					/* FIXME: Do log error */
+				}
 			} else if (projectType == ProjectType.FakeCaptureProject)
 				ProjectUtils.SaveFakeLiveProject(openedProject, this);
 		}
@@ -302,13 +369,14 @@ namespace LongoMatch.Gui
 		{
 			Project project;
 			ProjectType projectType;
+			CapturePropertiesStruct captureProps;
 			
 			if (!PromptCloseProject())
 				return;
 			
-			ProjectUtils.CreateNewProject(this, out project, out projectType);	
+			ProjectUtils.CreateNewProject(this, out project, out projectType, out captureProps);	
 			if (project != null)
-				SetProject(project, projectType);
+				SetProject(project, projectType, captureProps);
 		}
 		
 		protected virtual void OnOpenActivated(object sender, System.EventArgs e)
@@ -321,10 +389,10 @@ namespace LongoMatch.Gui
 			opd.TransientFor = this;
 
 			if (opd.Run() == (int)ResponseType.Ok)
-				project = opd.GetSelection();
+				project = opd.SelectedProject;
 			opd.Destroy();
 			if (project != null)
-				SetProject(MainClass.DB.GetProject(project.File), ProjectType.FileProject);
+				SetProject(MainClass.DB.GetProject(project.File), ProjectType.FileProject, new CapturePropertiesStruct());
 		}
 		
 		protected virtual void OnSaveProjectActionActivated(object sender, System.EventArgs e)
@@ -426,7 +494,7 @@ namespace LongoMatch.Gui
 		protected virtual void OnHelpAction1Activated(object sender, System.EventArgs e)
 		{
 			try {
-				System.Diagnostics.Process.Start("http://www.longomatch.ylatuya.es/documentation/manual.html");
+				System.Diagnostics.Process.Start(Constants.MANUAL);
 			} catch {}
 		}
 		
@@ -435,7 +503,7 @@ namespace LongoMatch.Gui
 			Version version = Assembly.GetExecutingAssembly().GetName().Version;
 			Gtk.AboutDialog about = new AboutDialog();
 			if (Environment.OSVersion.Platform == PlatformID.Unix)
-				about.ProgramName = "LongoMatch";
+				about.ProgramName = Constants.PROJECT_NAME;
 			about.Version = String.Format("{0}.{1}.{2}",version.Major,version.Minor,version.Build);
 			about.Copyright = Constants.COPYRIGHT;
 			about.Website = Constants.WEBSITE;
@@ -461,7 +529,7 @@ namespace LongoMatch.Gui
 				hpaned.Position = args.Requisition.Width;
 		}		
 
-		protected virtual void OnPlayerbin1Error(object o,LongoMatch.Video.Handlers.ErrorArgs args)
+		protected virtual void OnPlayerbin1Error(object o, ErrorArgs args)
 		{
 			MessagePopup.PopupMessage(this, MessageType.Info,
 			                          Catalog.GetString("The actual project will be closed due to an error in the media player:")+"\n" +args.Message);
@@ -506,7 +574,7 @@ namespace LongoMatch.Gui
 			} else {
 				switch (key){
 					case Constants.TOGGLE_PLAY:
-						capturerBin.ToggleCapture();
+						capturerBin.TogglePause();
 						break;			
 				}	
 			}
@@ -543,7 +611,13 @@ namespace LongoMatch.Gui
 			CloseAndQuit();	
 			return true;
 		}
-		#endregion	
 		
+		protected virtual void OnCapturerBinError (object o, ErrorArgs args)
+		{
+			MessagePopup.PopupMessage(this, MessageType.Info,
+			                          Catalog.GetString("An error occured in the video capturer and the current project will be closed:")+"\n" +args.Message);
+			CloseOpenedProject(true);
+		}
+		#endregion	
 	}
-}
\ No newline at end of file
+}
